@@ -93,13 +93,17 @@
 #'
 #'
 #' @param map A \code{\link{redist_map}} object.
-#' @param nsims The number of samples to draw, not including warmup.
+#' @param nsims The number of samples to draw per chain, not including warmup.
+#' @param chains The number of parallel chains to run. Each chain will have
+#'   `nsims` draws. If `init_plan` is sampled, each chain will be initialized
+#'   with its own sampled plan. Defaults to 1.
 #' @param warmup The number of warmup samples to discard.
-#' @param init_plan A vector containing the congressional district labels
-#' of each geographic unit. The default is \code{NULL}. If not provided,
-#' a random initial plan will be generated using \code{redist_smc}. You can also
-#' request to initialize using \code{redist.rsg} by supplying 'rsg', though this is
-#' not recommended behavior.
+#' @param init_plan The initial state of the map, provided as a single vector
+#'   to be shared across all chains, or a matrix with `chains` columns.
+#'   If not provided, will default to the reference map of the `map` object, or if
+#'   none exists, will sample a random initial state using \code{redist_smc}. You can
+#'   also request a random initial state for each chain by setting
+#'   \code{init_plan="sample"}.
 #' @param constraints A `redist_constr` object.
 #' @param thin The amount by which to thin the Markov Chain. The
 #' default is \code{1}.
@@ -126,13 +130,20 @@
 #' @param adjswaps Flag to restrict swaps of beta so that only
 #' values adjacent to current constraint are proposed. The default is
 #' \code{TRUE}.
+#' @param ncores The number of parallel processes to run. Defaults to the
+#'   number of available cores, capped at the number of chains.
+#' @param cl_type The cluster type (see [parallel::makeCluster()]). Safest is
+#'   `"PSOCK"`, but `"FORK"` may be faster on non-Windows systems.
+#' @param return_all If `TRUE` return all sampled plans; otherwise, just return
+#'   the final plan from each chain.
 #' @param init_name a name for the initial plan, or \code{FALSE} to not include
 #' the initial plan in the output.  Defaults to the column name of the
 #' existing plan, or "\code{<init>}" if the initial plan is sampled.
 #' @param verbose Whether to print initialization statement. Default is \code{TRUE}.
-#' @param nthin Deprecated. Use `thin`.
 #'
 #' @return A \code{\link{redist_plans}} object containing the simulated plans.
+#'   If `chains > 1`, the output will include a `chain` column indicating which
+#'   chain each plan came from.
 #' @concept simulate
 #' @export
 #'
@@ -151,42 +162,50 @@
 #'     pop_tol = 0.05)
 #' sims <- redist_flip(map = iowa_map, nsims = 100)
 #'
-redist_flip <- function(map, nsims, warmup = 0, init_plan,
+#' # Multiple chains for convergence diagnostics
+#' sims_chains <- redist_flip(iowa_map, nsims = 20, chains = 2, ncores = 2)
+#'
+redist_flip <- function(map, nsims, chains = 1, warmup = 0, init_plan = NULL,
                         constraints = add_constr_edges_rem(redist_constr(map), 0.4),
                         thin = 1, eprob = 0.05, lambda = 0, temper = FALSE,
                         betaseq = "powerlaw", betaseqlength = 10, betaweights = NULL,
                         adapt_lambda = FALSE, adapt_eprob = FALSE, exact_mh = FALSE,
-                        adjswaps = TRUE, init_name = NULL, verbose = TRUE, nthin) {
+                        adjswaps = TRUE, ncores = NULL, cl_type = "PSOCK",
+                        return_all = TRUE, init_name = NULL, verbose = TRUE) {
 
-    if (!missing(nthin)) {
-        thin <- nthin
-        .Deprecated(msg = 'Argument `nthin` is deprecated in favor of `thin` in redist 4.2.0 for consistency.')
+    chains <- as.integer(chains)
+    if (chains < 1) {
+        cli::cli_abort("{.arg chains} must be positive.")
     }
-    if (verbose) {
-        ## Initialize ##
+
+    verbosity <- ifelse(verbose, 3, 1)
+
+    if (verbosity > 0) {
         cli::cli({
             cli::cli_h1(cli::col_red("redist_flip()"))
             cli::cli_h2(cli::col_red("Automated Redistricting Simulation Using Markov Chain Monte Carlo"))
         })
     }
+
     # process raw inputs
     nprec <- nrow(map)
     map <- validate_redist_map(map)
     adj <- get_adj(map)
     total_pop <- map[[attr(map, "pop_col")]]
     ndists <- attr(map, "ndists")
+    pop_bounds <- attr(map, "pop_bounds")
 
-    if (any(total_pop >= get_target(map)))
-        cli::cli_abort("Units ", which(total_pop >= get_target(map)),
-            " have population larger than the district target.\n",
+    if (any(total_pop >= pop_bounds[3])) {
+        cli::cli_abort("Units ", which(total_pop >= pop_bounds[3]),
+            " have population larger than the maximum district size.\n",
             "Redistricting impossible.")
+    }
 
     # process constraints
     if (!inherits(constraints, "redist_constr")) {
         cli::cli_abort("Not a {.cls redist_constr} object.")
     }
 
-
     if (!any(class(thin) %in% c("numeric", "integer"))) {
         cli::cli_abort("thin must be an integer")
     } else if (thin < 1) {
@@ -197,87 +216,197 @@ redist_flip <- function(map, nsims, warmup = 0, init_plan,
 
     pop_tol <- get_pop_tol(map)
 
-
+    # Handle init_plan for multiple chains
     exist_name <- attr(map, "existing_col")
-    if (missing(init_plan)) {
-        init_plan <- get_existing(map)
-
-        if (is.null(init_plan)) {
-            invisible(capture.output(init_plan <- redist_smc(map,
-                nsims = 1,
-                silent = TRUE
-            ), type = "message"))
-            init_plan <- as.matrix(init_plan) - 1L
 
+    if (is.null(init_plan)) {
+        if (!is.null(exist_name)) {
+            init_plans <- matrix(rep(vctrs::vec_group_id(get_existing(map)), chains), ncol = chains)
             if (is.null(init_name)) {
-                init_name <- "<init>"
+                init_names <- rep(exist_name, chains)
+            } else {
+                init_names <- rep(init_name, chains)
             }
-
         } else {
-            if (is.null(init_name)) init_name <- exist_name
-            init_plan <- vctrs::vec_group_id(x = init_plan)
-            components <- contiguity(adj, init_plan)
-            if (any(components > 1)) {
-                cli::cli_abort("init_plan does not point to a contiguous plan.")
-            }
+            init_plan <- "sample"
         }
     }
 
+    if (is.character(init_plan) && init_plan[1] == "sample") {
+        if (verbosity > 0) cli::cli_inform("Sampling initial plans with SMC")
+        init_plans <- get_plans_matrix(
+            redist_smc(map, chains, resample = TRUE, ref_name = FALSE,
+                       verbose = FALSE, silent = TRUE, ncores = 1))
+        if (is.null(init_name)) {
+            init_names <- paste0("<sample ", seq_len(chains), ">")
+        } else {
+            init_names <- paste(init_name, seq_len(chains))
+        }
+    } else if (!is.null(init_plan) && !is.character(init_plan)) {
+        if (is.matrix(init_plan)) {
+            if (ncol(init_plan) != chains) {
+                cli::cli_abort("{.arg init_plan} matrix must have {chains} column{?s}.")
+            }
+            init_plans <- init_plan
+        } else {
+            init_plans <- matrix(rep(vctrs::vec_group_id(as.integer(init_plan)), chains), ncol = chains)
+        }
+
+        if (is.null(init_name)) {
+            init_names <- paste0("<init ", seq_len(chains), ">")
+        } else if (is.matrix(init_plan) && chains > 1) {
+            init_names <- paste(init_name, seq_len(chains))
+        } else {
+            init_names <- rep(init_name, chains)
+        }
+    }
+
+    # Validate init_plans
+    if (nrow(init_plans) != nprec) {
+        cli::cli_abort("{.arg init_plan} must be as long as the number of units in `map`.")
+    }
+    if (max(init_plans) != ndists) {
+        cli::cli_abort("{.arg init_plan} must have the same number of districts as `map`.")
+    }
+    if (any(apply(init_plans, 2, function(x) any(contiguity(adj, x) > 1)))) {
+        cli::cli_abort("init_plan does not point to a contiguous plan.")
+    }
+
     adapt_lambda <- as.integer(adapt_lambda)
     adapt_eprob <- as.integer(adapt_eprob)
     exact_mh <- as.integer(exact_mh)
 
-    if (verbose) {
+    if (verbosity > 0) {
         cli::cli_alert_info("Preprocessing data.")
     }
 
-    preprocout <- redist.preproc(
-        adj = adj,
-        total_pop = total_pop,
-        init_plan = init_plan,
-        ndists = ndists,
-        pop_tol = pop_tol,
-        temper = temper,
-        betaseq = betaseq,
-        betaseqlength = betaseqlength,
-        betaweights = betaweights,
-        adjswaps = adjswaps,
-        maxiterrsg = 1,
-        verbose = verbose
-    )
+    # Set up parallel cluster if needed
+    if (is.null(ncores)) {
+        ncores <- parallel::detectCores()
+    }
+    ncores <- min(ncores, chains)
 
-    if (verbose) {
-        cli::cli_alert_info("Starting swMH().")
+    if (ncores > 1 && chains > 1) {
+        `%oper%` <- `%dorng%`
+        if (verbose) {
+            of <- ifelse(Sys.info()[['sysname']] == 'Windows',
+                         tempfile(pattern = paste0('flip_', substr(Sys.time(), 1, 10)), fileext = '.txt'),
+                         '')
+            cl <- parallel::makeCluster(ncores, type = cl_type, outfile = of,
+                                        methods = FALSE, useXDR = .Platform$endian != "little")
+        } else {
+            cl <- parallel::makeCluster(ncores, type = cl_type,
+                                        methods = FALSE, useXDR = .Platform$endian != "little")
+        }
+
+        doParallel::registerDoParallel(cl)
+        on.exit(parallel::stopCluster(cl))
+    } else {
+        `%oper%` <- `%do%`
     }
 
-    algout <- swMH(
-        aList = preprocout$data$adjlist,
-        cdvec = preprocout$data$init_plan,
-        popvec = preprocout$data$total_pop,
-        constraints = as.list(constraints),
-        nsims = nsims*thin + warmup,
-        eprob = eprob,
-        pct_dist_parity = preprocout$params$pctdistparity,
-        beta_sequence = preprocout$params$betaseq,
-        beta_weights = preprocout$params$betaweights,
-        lambda = lambda,
-        beta = preprocout$params$beta,
-        adapt_beta = preprocout$params$temperbeta,
-        adjswap = preprocout$params$adjswaps,
-        exact_mh = exact_mh,
-        adapt_lambda = adapt_lambda,
-        adapt_eprob = adapt_eprob,
-        verbose = as.logical(verbose)
-    )
+    # Run chains (in parallel or sequentially)
+    out_par <- foreach::foreach(
+        chain = seq_len(chains), .inorder = FALSE,
+        .packages = "redist"
+    ) %oper% {
+        if (verbose) cat("Starting chain ", chain, "\n", sep = "")
+        run_verbosity <- if (chain == 1 || verbosity == 3) verbosity else 0
 
-    algout <- redist.warmup.chain(algout, warmup = warmup)
-    algout <- redist.thin.chain(algout, thin = thin)
+        this_init <- init_plans[, chain]
 
+        preprocout <- redist.preproc(
+            adj = adj,
+            total_pop = total_pop,
+            init_plan = this_init,
+            ndists = ndists,
+            pop_tol = pop_tol,
+            temper = temper,
+            betaseq = betaseq,
+            betaseqlength = betaseqlength,
+            betaweights = betaweights,
+            adjswaps = adjswaps,
+            maxiterrsg = 1,
+            verbose = (run_verbosity > 0)
+        )
 
-    algout$plans <- algout$plans + 1L
+        if (run_verbosity > 0) {
+            cli::cli_alert_info("Starting swMH().")
+        }
+
+        t1_run <- Sys.time()
+        algout <- swMH(
+            aList = preprocout$data$adjlist,
+            cdvec = preprocout$data$init_plan,
+            popvec = preprocout$data$total_pop,
+            constraints = as.list(constraints),
+            nsims = nsims*thin + warmup,
+            eprob = eprob,
+            pop_lower = pop_bounds[1],
+            pop_upper = pop_bounds[3],
+            beta_sequence = preprocout$params$betaseq,
+            beta_weights = preprocout$params$betaweights,
+            lambda = lambda,
+            beta = preprocout$params$beta,
+            adapt_beta = preprocout$params$temperbeta,
+            adjswap = preprocout$params$adjswaps,
+            exact_mh = exact_mh,
+            adapt_lambda = adapt_lambda,
+            adapt_eprob = adapt_eprob,
+            verbose = (run_verbosity > 0)
+        )
+        t2_run <- Sys.time()
+
+        algout <- redist.warmup.chain(algout, warmup = warmup)
+        algout <- redist.thin.chain(algout, thin = thin)
+
+        algout$plans <- algout$plans + 1L
+        storage.mode(algout$plans) <- "integer"
+
+        algout$l_diag <- list(
+            runtime = as.numeric(t2_run - t1_run, units = "secs")
+        )
+
+        algout$mh <- mean(algout$mhdecisions)
+
+        if (!return_all) {
+            algout$plans <- algout$plans[, ncol(algout$plans), drop = FALSE]
+            algout$mhdecisions <- algout$mhdecisions[length(algout$mhdecisions)]
+            algout$distance_parity <- algout$distance_parity[length(algout$distance_parity)]
+            algout$mhprob <- algout$mhprob[length(algout$mhprob)]
+            algout$pparam <- algout$pparam[length(algout$pparam)]
+            algout$beta_sequence <- algout$beta_sequence[length(algout$beta_sequence)]
+            algout$energy_psi <- algout$energy_psi[length(algout$energy_psi)]
+            algout$boundary_partitions <- algout$boundary_partitions[length(algout$boundary_partitions)]
+            algout$psi_store <- algout$psi_store[, ncol(algout$psi_store), drop = FALSE]
+        }
+
+        algout
+    }
+
+    # Combine results from all chains
+    plans <- lapply(out_par, function(algout) algout$plans)
+    each_len <- ncol(plans[[1]])
+    plans <- do.call(cbind, plans)
+    storage.mode(plans) <- "integer"
+
+    mh <- sapply(out_par, function(algout) algout$mh)
+    l_diag <- lapply(out_par, function(algout) algout$l_diag)
+
+    mhdecisions <- do.call(c, lapply(out_par, function(x) x$mhdecisions))
+    distance_parity <- do.call(c, lapply(out_par, function(x) x$distance_parity))
+    mhprob <- do.call(c, lapply(out_par, function(x) x$mhprob))
+    pparam <- do.call(c, lapply(out_par, function(x) x$pparam))
+    beta_sequence <- do.call(c, lapply(out_par, function(x) x$beta_sequence))
+    energy_psi <- do.call(c, lapply(out_par, function(x) x$energy_psi))
+    boundary_partitions <- do.call(c, lapply(out_par, function(x) x$boundary_partitions))
+    psi_store <- do.call(cbind, lapply(out_par, function(x) x$psi_store))
+
+    # Pre-compute repeated vectors for mutate (avoid scoping issues)
+    boundary_partitions_rep <- rep(boundary_partitions, each = ndists)
 
     out <- new_redist_plans(
-        plans = algout$plans,
+        plans = plans,
         map = map,
         algorithm = "flip",
         wgt = NULL,
@@ -290,32 +419,51 @@ redist_flip <- function(map, nsims, warmup = 0, init_plan,
         adapt_lambda = as.logical(adapt_lambda),
         warmup = warmup,
         nthin = thin,
-        mh_acceptance = mean(algout$mhdecisions),
-        final_eprob = algout$final_eprob,
-        final_lambda = algout$final_lambda,
-        distance_original = algout$distance_original,
-        beta_sequence = algout$beta_sequence
+        mh_acceptance = mh,
+        version = packageVersion("redist"),
+        diagnostics = l_diag
     ) %>%
         mutate(
-            distance_parity = rep(algout$distance_parity, each = ndists),
-            mhdecisions = rep(algout$mhdecisions, each = ndists),
-            mhprob = rep(algout$mhprob, each = ndists),
-            pparam = rep(algout$pparam, each = ndists),
-            beta_sequence = rep(algout$beta_sequence, each = ndists),
-            energy_psi = rep(algout$energy_psi, each = ndists),
-            boundary_partitions = rep(algout$boundary_partitions, each = ndists),
-            boundary_ratio = rep(algout$boundary_partitions, each = ndists)
+            distance_parity = rep(distance_parity, each = ndists),
+            mhdecisions = rep(mhdecisions, each = ndists),
+            mhprob = rep(mhprob, each = ndists),
+            pparam = rep(pparam, each = ndists),
+            beta_sequence = rep(beta_sequence, each = ndists),
+            energy_psi = rep(energy_psi, each = ndists),
+            boundary_partitions = boundary_partitions_rep,
+            boundary_ratio = boundary_partitions_rep
         )
 
-    add_tb <- apply(algout$psi_store, 1, function(x) rep(x, each = ndists)) %>%
+    # Add chain column if multiple chains
+    if (chains > 1) {
+        out <- out %>%
+            mutate(chain = rep(seq_len(chains), each = each_len * ndists))
+    }
+
+    # Add constraint columns
+    add_tb <- apply(psi_store, 1, function(x) rep(x, each = ndists)) %>%
         dplyr::as_tibble() %>%
         dplyr::rename_with(function(x) paste0("constraint_", x))
 
     names_tb <- names(add_tb)[apply(add_tb, 2, function(x) { !all(x == 0) })]
     out <- bind_cols(out, select(add_tb, all_of(names_tb)))
 
-    if (!is.null(init_name) && !isFALSE(init_name)) {
-        out <- add_reference(out, init_plan, init_name)
+    # Add reference plans
+    if (!is.null(init_names) && !isFALSE(init_name)) {
+        if (chains == 1) {
+            out <- add_reference(out, init_plans[, 1], init_names[1])
+        } else if (all(init_names[1] == init_names)) {
+            out <- add_reference(out, init_plans[, 1], init_names[1])
+        } else {
+            out <- Reduce(function(cur, idx) {
+                add_reference(cur, init_plans[, idx], init_names[idx]) %>%
+                    mutate(chain = dplyr::coalesce(chain, idx))
+            }, rev(seq_len(chains)), init = out)
+        }
+    }
+
+    if (chains > 1) {
+        out <- dplyr::relocate(out, chain, .after = "draw")
     }
 
     out
@@ -392,10 +540,11 @@ redist_flip_anneal <- function(map,
     adj <- get_adj(map)
     total_pop <- map[[attr(map, "pop_col")]]
     ndists <- attr(map, "ndists")
+    pop_bounds <- attr(map, "pop_bounds")
 
-    if (any(total_pop >= get_target(map))) {
-        cli::cli_abort("Units ", which(total_pop >= get_target(map)),
-            " have population larger than the district target.\n",
+    if (any(total_pop >= pop_bounds[3])) {
+        cli::cli_abort("Units ", which(total_pop >= pop_bounds[3]),
+            " have population larger than the maximum district size.\n",
             "Redistricting impossible.")
     }
 
@@ -476,7 +625,8 @@ redist_flip_anneal <- function(map,
         constraints = as.list(constraints),
         nsims = 100,
         eprob = eprob,
-        pct_dist_parity = preprocout$params$pctdistparity,
+        pop_lower = pop_bounds[1],
+        pop_upper = pop_bounds[3],
         beta_sequence = preprocout$params$betaseq,
         beta_weights = preprocout$params$betaweights,
         lambda = lambda,
