@@ -6,7 +6,6 @@
 #endif
 
 #include <vector>
-#include <random>
 #include <limits>
 #include <RcppArmadillo.h>
 #include "redist_types.h"
@@ -17,20 +16,7 @@
 using namespace Rcpp;
 using namespace arma;
 
-// INITIALIZE MT RNG
-extern std::random_device rd;
-extern std::mt19937 generator;
-extern std::uniform_real_distribution<double> unif;
-
-/*
- * Generate a uniform random integer in [0, max).
- */
-int rint(int max);
-
-/*
- * Generate a random integer in [0, max) according to weights.
- */
-int rint(int max, vec cum_wgts);
+#include "random.h"
 
 /*
  * Get the index of the k-th smallest element of x
